@@ -24,8 +24,7 @@ class Status:
                 try:
                     self.api.poll()
                 except linuxcnc.error as detail:
-                    self.father.framework.utils.service.service_write(
-                        {"command": "launch:machine:error", "message": detail, "data": False})
+                    self.father.framework.utils.service.service_write({"command": "launch:machine:error", "message": detail, "data": False})
 
                 self.father.framework.machine.info = {}
                 for x in dir(self.api):
@@ -58,9 +57,9 @@ class Status:
                         "spindle": {
                             "enabled": self.father.framework.machine.info["spindle"][0]["enabled"],
                             "direction": self.father.framework.machine.info["spindle"][0]["direction"],
-                            "speed": self.father.framework.machine.info["spindle"][0]["speed"],
-                            "max_speed": int(self.father.framework.machine.get_user_config_value("SPINDLE", "MAX_SPEED") or 24000),
-                            "default_speed": int(inifile.find("DISPLAY", "DEFAULT_SPINDLE_SPEED")),
+                            "velocity": self.father.framework.machine.info["spindle"][0]["speed"],
+                            "min_velocity": int(inifile.find("SPINDLE_0", "MIN_FORWARD_VELOCITY") or 0),
+                            "max_velocity": int(inifile.find("SPINDLE_0", "MAX_FORWARD_VELOCITY") or 24000),
                             "min_override": float(inifile.find("DISPLAY", "MIN_SPINDLE_OVERRIDE")),
                             "max_override": float(inifile.find("DISPLAY", "MAX_SPINDLE_OVERRIDE")),
                             "override": self.father.framework.machine.info["spindle"][0]["override"],
@@ -68,11 +67,10 @@ class Status:
                         },
                         "feed": {
                             "max_override": float(inifile.find("DISPLAY", "MAX_FEED_OVERRIDE")),
-                            "rate": float(self.father.framework.machine.info["feedrate"])
+                            "override": float(self.father.framework.machine.info["feedrate"])
                         },
-                        "ext_info": self.father.framework.machine.get_user_config_items("EXTINFO"),
-                        "max_linear_velocity": float(inifile.find("DISPLAY", "MAX_LINEAR_VELOCITY")),
                         "max_velocity": float(self.father.framework.machine.info["max_velocity"]),
+                        "max_linear_velocity": float(inifile.find("DISPLAY", "MAX_LINEAR_VELOCITY")),
                         "default_linear_velocity": float(inifile.find("DISPLAY", "DEFAULT_LINEAR_VELOCITY")),
                         "max_angular_velocity": float(inifile.find("DISPLAY", "MAX_ANGULAR_VELOCITY")),
                         "default_angular_velocity": float(inifile.find("DISPLAY", "DEFAULT_ANGULAR_VELOCITY"))
@@ -114,10 +112,6 @@ class Status:
                         "item": self.father.framework.machine.info["tool_table"][0]
                     }
 
-                    current_gcode = next((code for code in self.father.framework.machine.info["gcodes"] if 540 <= code <= 593), None)
-                    if current_gcode:
-                        user_data["data"]["current_gcode"] = "G" + str(current_gcode)
-
                     if user_data["task_state"] == 4:
                         self.father.framework.machine.task_state = True
                     else:
